# vihhlima_image_processing

Description. 
The package package_name is used to:

	Utils:
		- Read image
		- Save image


## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install vihhlima_image_processing
```

## Usage

```python
from vihhlima_image_processing.utils import io
io.read_image(path)
```

## Author
Vitor Lima

## License
[MIT](https://choosealicense.com/licenses/mit/)